"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var pug = require("pug");
var vue_template_compiler_1 = require("vue-template-compiler");
function parseTemplate(tpl, documentation, handlers, filePath) {
    if (tpl && tpl.content) {
        var template = tpl.attrs && tpl.attrs.lang === 'pug'
            ? pug.render(tpl.content, { filename: filePath })
            : tpl.content;
        var ast = vue_template_compiler_1.compile(template, { comments: true }).ast;
        if (ast) {
            traverse(ast, documentation, handlers, { functional: !!tpl.attrs.functional });
        }
    }
}
exports.default = parseTemplate;
function traverse(templateAst, documentation, handlers, options) {
    if (templateAst.type === 1) {
        handlers.forEach(function (handler) {
            handler(documentation, templateAst, options);
        });
        if (templateAst.children) {
            for (var _i = 0, _a = templateAst.children; _i < _a.length; _i++) {
                var childNode = _a[_i];
                if (isASTElement(childNode)) {
                    traverse(childNode, documentation, handlers, options);
                }
            }
        }
    }
}
exports.traverse = traverse;
function isASTElement(node) {
    return !!node && node.children !== undefined;
}
//# sourceMappingURL=parse-template.js.map